package DE_EPAGES::Object::t::LastUpdate;
use base DE_EPAGES::Database::API::Test;

use strict;
use Test::More tests => 4;
use DE_EPAGES::Object::API::Factory qw( LoadObjectByPath LoadClassByAlias LoadRootObject ExistsObjectByPath );
use DE_EPAGES::Core::API::PerlTools qw ( GetCurrentDateTime );

use constant TEST_ALIAS => 'Test';
use constant TEST_PATH => '/'.TEST_ALIAS;

## no critic qw(ProhibitMagicNumbers)

sub init {
    LoadRootObject()->insertChild('Object', { Alias => TEST_ALIAS });
}

sub cleanup {
    LoadObjectByPath(TEST_PATH)->delete if ExistsObjectByPath(TEST_PATH);
}

sub test {
    my $self = shift;

    my $TestRoot = LoadObjectByPath(TEST_PATH);
    my $Site = $TestRoot->insertChild('Site', { Alias => 'TestSite' });

    my $UnitClass = LoadClassByAlias('UnitOfMeasurement');

    my $Now = GetCurrentDateTime(); # remember the time before deletion
    my $Iterator = $Site->getCreatedObjects($UnitClass, $Now);
    is $Iterator->count, 0, 'before created';

    my $Unit1 = $Site->insertChild('UnitOfMeasurement', {
        Alias => 'Elle',
        Type => 'length',
        Factor => '0.34',
    });

    $Iterator = $Site->getCreatedObjects($UnitClass, $Now);
    is $Iterator->count, 1, 'getCreatedObjects';
    my $hCreated = $Iterator->next;
    is $hCreated->{'Object'}->id, $Unit1->id, 'object ID';
    ok (DateTime->compare( $Now, $hCreated->{CreatedOn} ) < 1, 'CreatedOn');

}

__PACKAGE__->runScript;
